@@ -33,9 +33,10 @@
 #  define NETWORKMANAGERQT_DEPRECATED_NO_EXPORT NETWORKMANAGERQT_NO_EXPORT NETWORKMANAGERQT_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define NETWORKMANAGERQT_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef NETWORKMANAGERQT_NO_DEPRECATED
+#    define NETWORKMANAGERQT_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
